{% extends "datebook/base.html" %}
{% load i18n %}

{% block datebook_content %}
<div class="row">
    <div class="small-12 medium-6 large-4 columns">
        <p><a href="{% url 'datebook:current-month' author=user %}" class="button large expand radius"><i class="icon-calendar"></i> {% blocktrans %}See current month{% endblocktrans %}</a></p>
    </div>
    <div class="small-12 medium-6 large-4 columns">
        <p><a href="{% url 'datebook:day-models' author=user %}" class="button large expand radius"><i class="icon-insert-template"></i> {% blocktrans %}Manage your models{% endblocktrans %}</a></p>
    </div>
    <div class="small-12 medium-12 large-4 columns">
        <p><a href="{% url 'datebook:current-day' author=user %}" class="button success large expand radius"><i class="icon-pencil"></i> {% blocktrans %}Fill your current day{% endblocktrans %}</a></p>
    </div>
</div>
<hr/>

<ul class="inline-list">
    {% spaceless %}{% for item in object_list %}
        <li>
            <a href="{% url 'datebook:author-detail' author=item.author__username %}" class="button small radius">{{ item.author__username }}</a>
            {% comment %}<p>Updated on {{ item.modified|timesince }}</p>{% endcomment %}
        </li>
    {% endfor %}{% endspaceless %}
        {% if user.is_superuser or perms.datebook.add_datebook %}<li>
            <a href="{% url 'datebook:create' %}" class="button success small radius"><i class="icon-add-circle"></i> {% blocktrans %}Open a new datebook for a new user{% endblocktrans %}</a>
        </li>{% endif %}
</ul>
 {% endblock %}
