{% load i18n djangocodemirror_assets djangocodemirror_inputs %}
{% get_current_language as LANGUAGE_CODE %}
{% djangocodemirror_get_bundles field %}
<script type="text/javascript">
//<![CDATA[
DCM_lang = "{{ LANGUAGE_CODE }}";
$(document).ready(function() {
    var content_codemirror_instance = $('#{{ field.auto_id }}').djangocodemirror({{ field|djangocodemirror_init_input }});
});
//]]>
</script>